@@ -1,7 +1,7 @@
 """
 Type annotations for route53-recovery-cluster service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_route53_recovery_cluster/type_defs/)
 
 Usage::
 
@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import RoutingControlStateType
 
 if sys.version_info >= (3, 9):
@@ -71,6 +73,7 @@ UpdateRoutingControlStateRequestRequestTypeDef = TypedDict(
     {
         "RoutingControlArn": str,
         "RoutingControlState": RoutingControlStateType,
+        "SafetyRulesToOverride": NotRequired[Sequence[str]],
     },
 )
 
@@ -78,5 +81,6 @@ UpdateRoutingControlStatesRequestRequestTypeDef = TypedDict(
     "UpdateRoutingControlStatesRequestRequestTypeDef",
     {
         "UpdateRoutingControlStateEntries": Sequence["UpdateRoutingControlStateEntryTypeDef"],
+        "SafetyRulesToOverride": NotRequired[Sequence[str]],
     },
 )
